@@ -9,15 +9,16 @@
 import Graphics.UI.Gtk
 
 import Control.Concurrent
+import Control.Applicative ((<$>))
 
 main :: IO ()
 main = do
   initGUI
   dia <- dialogNew
   dialogAddButton dia stockClose ResponseClose
-  contain <- dialogGetUpper dia
+  contain <- castToBox <$> dialogGetContentArea dia
   pb <- progressBarNew
-  boxPackStartDefaults contain pb
+  boxPackStart contain pb PackNatural 0
   widgetShowAll dia
   forkIO (doTask pb)
 
